import { Notifier } from "./notifier";
import { InternalMessage, JoinedRoom, LeftRoom, ParticipantRole, RoomEvent, RoomState, UserNickname } from "./constants";
import { Connection } from "./connection";
export declare class Room {
    #private;
    protected notifier: Notifier<RoomEvent, InternalMessage>;
    protected connection: Connection;
    _id: string;
    _name: string;
    _pin: string;
    _nickname: string;
    constructor(connection: Connection, name: string, pin: string, nickname: UserNickname, creationTime: number);
    processEvent(e: InternalMessage): Promise<void>;
    join(pc: RTCPeerConnection, nickname?: UserNickname, config?: {
        [key: string]: string;
    }): Promise<JoinedRoom>;
    updateState(config?: {
        [key: string]: string;
    }): Promise<void>;
    destroyRoom(): Promise<void>;
    leaveRoom(): Promise<LeftRoom>;
    evictParticipant(nickname: UserNickname): Promise<void>;
    renameParticipant(nickname: UserNickname, newNickname: UserNickname): Promise<void>;
    sendMessage(msg: string): Promise<void>;
    changeQuality(trackId: string, quality: string, tid: number): Promise<void>;
    muteTrack(trackId: string, mute: boolean): Promise<void>;
    on(event: RoomEvent, callback: (arg0: InternalMessage) => void): Room;
    off(event: RoomEvent, callback: (arg0: InternalMessage) => void): Room;
    id(): string;
    name(): string;
    pin(): string;
    nickname(): string;
    pc(): RTCPeerConnection;
    role(): ParticipantRole;
    invite(): string;
    state(): RoomState;
    creationTime(): number;
}
